@@ -170,7 +170,7 @@ class ProtoWrapper:
                 bug.cloud.CopyFrom(cloud)
         if "package" in kwargs:
             package = kwargs.get("package")
-            if isinstance(package, pb2.Packgae):
+            if isinstance(package, pb2.Package):
                 bug.package.CopyFrom(package)
         if "container" in kwargs:
             container = kwargs.get("container")
